# This file was auto-generated by Fern from our API Definition.

import typing

BreakdownTypes = typing.Union[
    typing.Literal["none", "voice", "user", "api_keys", "all_api_keys", "product_type", "model"], typing.Any
]
