# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class VoiceSharingModerationCheckResponseModel(UncheckedBaseModel):
    date_checked_unix: typing.Optional[int] = None
    name_value: typing.Optional[str] = None
    name_check: typing.Optional[bool] = None
    description_value: typing.Optional[str] = None
    description_check: typing.Optional[bool] = None
    sample_ids: typing.Optional[typing.List[str]] = None
    sample_checks: typing.Optional[typing.List[float]] = None
    captcha_ids: typing.Optional[typing.List[str]] = None
    captcha_checks: typing.Optional[typing.List[float]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
