# This file was auto-generated by Fern from our API Definition.

from .body_update_member_v_1_workspace_members_post_workspace_role import (
    BodyUpdateMemberV1WorkspaceMembersPostWorkspaceRole,
)

__all__ = ["BodyUpdateMemberV1WorkspaceMembersPostWorkspaceRole"]
