# This file was auto-generated by Fern from our API Definition.

import typing

SpeechHistoryItemResponseModelVoiceCategory = typing.Union[
    typing.Literal["premade", "cloned", "generated", "professional"], typing.Any
]
