# This file was auto-generated by Fern from our API Definition.

import typing

ReviewStatus = typing.Union[
    typing.Literal["not_requested", "pending", "declined", "allowed", "allowed_with_changes"], typing.Any
]
