# This file was auto-generated by Fern from our API Definition.

import typing

ProjectSnapshotUploadResponseModelStatus = typing.Union[
    typing.Literal["success", "in_queue", "pending", "failed"], typing.Any
]
