# This file was auto-generated by Fern from our API Definition.

import typing

SubscriptionResponseModelCharacterRefreshPeriod = typing.Union[
    typing.Literal["monthly_period", "annual_period"], typing.Any
]
