# This file was auto-generated by Fern from our API Definition.

import typing

VoiceSharingResponseModelCategory = typing.Union[
    typing.Literal["generated", "professional", "high_quality", "famous"], typing.Any
]
