# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
from .subscription_response import SubscriptionResponse
import typing
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class User(UncheckedBaseModel):
    subscription: SubscriptionResponse
    is_new_user: bool
    xi_api_key: str
    can_use_delayed_payment_methods: bool
    is_onboarding_completed: bool
    is_onboarding_checklist_completed: bool
    first_name: typing.Optional[str] = None
    is_api_key_hashed: typing.Optional[bool] = None
    xi_api_key_preview: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
