# This file was auto-generated by Fern from our API Definition.

import typing

GetTranscriptForDubV1DubbingDubbingIdTranscriptLanguageCodeGetRequestFormatType = typing.Union[
    typing.Literal["srt", "webvtt"], typing.Any
]
